"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProxyContentResolver = exports.DefaultContentResolver = void 0;
class DefaultContentResolver {
    constructor(ipfsGateway) {
        this.ipfsGateway = ipfsGateway !== null && ipfsGateway !== void 0 ? ipfsGateway : ((id) => `https://ipfs.io/ipfs/${id}`);
    }
    resolve(url) {
        return __awaiter(this, void 0, void 0, function* () {
            if (url.startsWith('ipfs://')) {
                url = this.ipfsGateway(url.slice(7));
            }
            if (!(url.startsWith('https://') || url.startsWith('http://'))) {
                throw new Error('Unknown URL: ' + url);
            }
            return Buffer.from(yield (yield fetch(url)).arrayBuffer());
        });
    }
}
exports.DefaultContentResolver = DefaultContentResolver;
class ProxyContentResolver extends DefaultContentResolver {
    constructor({ ipfsGateway, urlProxy } = {}) {
        super(ipfsGateway);
        this.urlProxy = urlProxy == null ? (url) => url : urlProxy;
    }
    resolve(url) {
        return super.resolve(this.urlProxy(url));
    }
}
exports.ProxyContentResolver = ProxyContentResolver;
ProxyContentResolver.replaceable = '%URL%';
