import { Address, AssetsSDK, TonClient4, TonClient4Parameters } from './external';
import { WalletConnector, WalletConnectorParams, Wallet, Account, WalletApp } from './interfaces';
import { IpfsGateway, UrlProxy } from './content-resolver';
export interface JettonTransferRequest {
    jetton: Address;
    to: Address;
    amount: bigint;
    customPayload?: string;
    forwardAmount?: bigint;
    forwardPayload?: string;
}
export interface TonTransferRequest {
    to: Address;
    amount: bigint;
    comment?: string;
}
export type Network = 'mainnet' | 'testnet';
export interface MerchantParams {
    tonAddress: Address | string;
    jettonAddress?: Address | string;
}
export interface ContentResolverParams {
    ipfsGateway?: IpfsGateway;
    urlProxy?: UrlProxy | string;
}
export interface GameFiInitializationParams {
    network?: Network;
    connector?: WalletConnector | WalletConnectorParams;
    client?: TonClient4 | TonClient4Parameters;
    contentResolver?: ContentResolverParams;
    merchant?: MerchantParams;
}
export interface Merchant {
    tonAddress: Address;
    jettonAddress?: Address;
}
export interface GameFiConstructorParams {
    walletConnector: WalletConnector;
    assetsSdk: AssetsSDK;
    merchant?: Merchant;
}
export declare abstract class GameFiBase {
    readonly walletConnector: WalletConnector;
    readonly assetsSdk: AssetsSDK;
    readonly merchant?: Merchant;
    constructor(params: GameFiConstructorParams);
    get wallet(): Wallet;
    get walletAccount(): Account;
    get walletAddress(): Address;
    get merchantAddress(): Address;
    get merchantJettonAddress(): Address;
    buyWithTon(params: Omit<TonTransferRequest, 'to'>): Promise<void>;
    transferTon(params: TonTransferRequest): Promise<void>;
    buyWithJetton(params: Omit<JettonTransferRequest, 'to' | 'jetton'>): Promise<void>;
    transferJetton(params: Omit<JettonTransferRequest, 'jetton'>): Promise<void>;
    openNftCollection(address: Address): import("@ton-community/assets-sdk").ExtendedOpenedContract<import("@ton-community/assets-sdk").NftCollection<string>>;
    openNftSale(address: Address): import("@ton-community/assets-sdk").ExtendedOpenedContract<import("@ton-community/assets-sdk").NftSale>;
    openNftItem(address: Address): import("@ton-community/assets-sdk").ExtendedOpenedContract<import("@ton-community/assets-sdk").NftItem>;
    openNftItemByIndex(collectionAddress: Address, itemIndex: bigint): Promise<import("@ton-community/assets-sdk").ExtendedOpenedContract<import("@ton-community/assets-sdk").NftItem>>;
    openSbtCollection(address: Address): import("@ton-community/assets-sdk").ExtendedOpenedContract<import("@ton-community/assets-sdk").SbtCollection<unknown>>;
    openJetton(address: Address): import("@ton-community/assets-sdk").ExtendedOpenedContract<import("@ton-community/assets-sdk").JettonMinter>;
    openJettonWallet(address: Address): import("@ton-community/assets-sdk").ExtendedOpenedContract<import("@ton-community/assets-sdk").JettonWallet>;
    connectWallet(app: WalletApp): Promise<void>;
    onWalletChange(...params: Parameters<WalletConnector['onStatusChange']>): () => void;
    disconnectWallet(): Promise<void>;
    private createMessagePayload;
    protected static createDependencies(params?: GameFiInitializationParams): Promise<GameFiConstructorParams>;
    protected static addressToObject(address: Address | string): Address;
    protected static isTonConnectUiInstance(instance: unknown): instance is WalletConnector;
    protected static createConnectUiWorkaround(params?: WalletConnectorParams): WalletConnector;
}
