"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConnectWalletButton = void 0;
const dropdown_1 = require("./dropdown");
const consts_1 = require("./consts");
const utils_1 = require("./utils");
const icons_1 = require("./icons");
class ConnectWalletButton extends Phaser.GameObjects.Container {
    constructor(connector, scene, x = 0, y = 0, params = {}) {
        var _a;
        super(scene, x, y);
        this.connector = connector;
        this.wallet = null;
        this.changeIconTimer = null;
        this.connectWallet = () => __awaiter(this, void 0, void 0, function* () {
            try {
                this.disable();
                yield this.connector.openSingleWalletModal(this.connectionSourceName);
            }
            catch (error) {
                this.onError(error);
            }
            finally {
                this.enable();
            }
        });
        this.disconnectWallet = () => __awaiter(this, void 0, void 0, function* () {
            try {
                this.disable();
                yield this.connector.disconnect();
            }
            catch (error) {
                this.onError(error);
            }
            finally {
                this.enable();
            }
        });
        this.copyAddress = (item) => __awaiter(this, void 0, void 0, function* () {
            if (this.wallet == null) {
                return;
            }
            try {
                yield navigator.clipboard.writeText((0, utils_1.rawAddressToFriendly)(this.wallet.account.address));
                const oldText = item.text.text;
                item.text.setText(this.locale.addressCopied);
                setTimeout(() => {
                    try {
                        item.text.setText(oldText);
                    }
                    catch (error) {
                    }
                }, 500);
            }
            catch (error) {
                this.onError(error);
            }
        });
        this.toggleDropdownMenu = () => {
            if (this.dropdownMenu == null) {
                return;
            }
            this.dropdownMenu.setVisible(!this.dropdownMenu.visible);
        };
        this.params = params;
        this.connectionSourceName = params.walletApp || 'telegram-wallet';
        this.onError = this.params.onError
            ? this.params.onError
            : (error) => {
                throw error;
            };
        this.loadAssets(scene);
        const locale = consts_1.locales[(_a = params.language) !== null && _a !== void 0 ? _a : 'en'];
        this.locale = locale;
        const styleSchema = params.style === 'dark' ? consts_1.buttonDesign.dark : consts_1.buttonDesign.light;
        const backgroundColor = params.style === 'dark'
            ? (0, utils_1.hexToNumber)(styleSchema.backgroundColor)
            : (0, utils_1.hexToNumber)(styleSchema.backgroundColor);
        const btnCtr = new Phaser.GameObjects.Container(scene, 0, 0);
        const textObject = scene.add.text(consts_1.buttonDesign.horizontalPadding + consts_1.buttonDesign.icon.width, consts_1.buttonDesign.verticalPadding, locale.connectWallet, {
            color: styleSchema.fontColor,
            fontFamily: consts_1.buttonDesign.fontFamily,
            fontSize: consts_1.buttonDesign.fontSize
        });
        this.buttonText = textObject;
        const textWidth = textObject.width;
        const textHeight = textObject.height;
        const buttonWidth = textWidth +
            consts_1.buttonDesign.horizontalPadding * 2 +
            consts_1.buttonDesign.icon.width +
            consts_1.buttonDesign.icon.horizontalPadding;
        const buttonHeight = textHeight + consts_1.buttonDesign.verticalPadding * 2;
        this.buttonWidth = buttonWidth;
        this.buttonHeight = buttonHeight;
        this.currentIcon = styleSchema.icons.diamond;
        const button = scene.add.graphics({
            x: 0,
            y: 0,
            fillStyle: {
                color: this.wallet == null ? (0, utils_1.hexToNumber)(styleSchema.backgroundColor) : backgroundColor
            },
            lineStyle: { width: consts_1.buttonDesign.borderWidth, color: (0, utils_1.hexToNumber)(styleSchema.borderColor) }
        });
        button.fillRoundedRect(0, 0, buttonWidth, buttonHeight, consts_1.buttonDesign.borderRadius);
        button.strokeRoundedRect(0, 0, buttonWidth, buttonHeight, consts_1.buttonDesign.borderRadius);
        this.buttonBackground = button;
        btnCtr.on('pointerover', () => {
            scene.game.canvas.style.cursor = 'pointer';
            if (this.wallet != null) {
                this.repaintButtonBackground(styleSchema.backgroundColorHover, styleSchema.borderColor);
            }
            (0, utils_1.smoothScale)(scene.tweens, btnCtr, 1.02, 125);
        });
        btnCtr.on('pointerout', () => {
            scene.game.canvas.style.cursor = 'default';
            if (this.wallet != null) {
                this.repaintButtonBackground(styleSchema.backgroundColor, styleSchema.borderColor);
            }
            (0, utils_1.smoothScale)(scene.tweens, btnCtr, 1, 125);
        });
        btnCtr.on('pointerdown', () => {
            (0, utils_1.smoothScale)(scene.tweens, btnCtr, 0.98, 125);
        });
        btnCtr.on('pointerup', () => {
            (0, utils_1.smoothScale)(scene.tweens, btnCtr, 1.02, 125);
        });
        this.buttonContainer = btnCtr;
        textObject.setText('...');
        const walletChanged = (wallet) => {
            this.wallet = wallet;
            btnCtr.off('pointerdown', this.connectWallet);
            btnCtr.off('pointerdown', this.toggleDropdownMenu);
            if (wallet) {
                textObject.setText((0, utils_1.rawAddressToFriendly)(wallet.account.address, true));
                btnCtr.on('pointerdown', this.toggleDropdownMenu);
                this.setSchema(styleSchema);
            }
            else {
                textObject.setText(locale.connectWallet);
                btnCtr.on('pointerdown', this.connectWallet);
                this.setSchema(consts_1.buttonDesign.default);
            }
            if (this.params.onWalletChange) {
                this.params.onWalletChange(wallet);
            }
        };
        this.unsubscribeFromConnector = this.connector.onStatusChange(walletChanged);
        this.connector.connectionRestored.then((connected) => {
            if (!connected) {
                walletChanged(null);
            }
            this.enable();
        });
        this.setSize(this.buttonWidth, this.buttonHeight);
    }
    loadAssets(scene) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            yield (0, icons_1.loadIcons)(scene.textures);
            const icon = scene.add.image(consts_1.buttonDesign.horizontalPadding -
                consts_1.buttonDesign.icon.horizontalPadding +
                consts_1.buttonDesign.icon.width * 0.5, this.buttonHeight * 0.5, this.currentIcon);
            this.buttonIcon = icon;
            this.dropdownMenu = new dropdown_1.DropdownMenu(scene, 0, this.buttonHeight + consts_1.buttonDesign.dropDown.topMargin, {
                style: (_a = this.params.style) !== null && _a !== void 0 ? _a : 'light',
                items: [
                    {
                        icon: this.params.style === 'dark' ? consts_1.DARK_COPY : consts_1.LIGHT_COPY,
                        text: this.locale.copyAddress,
                        onClick: this.copyAddress
                    },
                    {
                        icon: this.params.style === 'dark' ? consts_1.DARK_DISCONNECT : consts_1.LIGHT_DISCONNECT,
                        text: this.locale.disconnectWallet,
                        onClick: () => {
                            this.toggleDropdownMenu();
                            this.disconnectWallet();
                        }
                    }
                ]
            });
            this.dropdownMenu.setVisible(false);
            this.buttonContainer.add([this.buttonBackground, this.buttonIcon, this.buttonText]);
            this.add([this.buttonContainer, this.dropdownMenu]);
            scene.add.existing(this);
        });
    }
    changeIcon(icon) {
        this.cancelIconChange();
        if (this.buttonIcon) {
            this.currentIcon = icon;
            this.buttonIcon.setTexture(icon);
        }
        else {
            this.changeIconTimer = setTimeout(() => {
                this.changeIcon(icon);
            }, 4);
        }
    }
    cancelIconChange() {
        if (this.changeIconTimer != null) {
            clearTimeout(this.changeIconTimer);
            this.changeIconTimer = null;
        }
    }
    disable() {
        this.buttonContainer.setInteractive(false);
    }
    enable() {
        this.buttonContainer.setInteractive(new Phaser.Geom.Rectangle(0, 0, this.buttonWidth, this.buttonHeight), Phaser.Geom.Rectangle.Contains);
    }
    setSchema(schema) {
        this.repaintButtonBackground(schema.backgroundColor, schema.borderColor);
        this.changeIcon(schema.icons.diamond);
        this.buttonText.setColor(schema.fontColor);
    }
    repaintButtonBackground(backgroundColor, borderColor) {
        this.buttonBackground.clear();
        this.buttonBackground.fillStyle((0, utils_1.hexToNumber)(backgroundColor));
        this.buttonBackground.lineStyle(consts_1.buttonDesign.borderWidth, (0, utils_1.hexToNumber)(borderColor));
        this.buttonBackground.fillRoundedRect(0, 0, this.buttonWidth, this.buttonHeight, consts_1.buttonDesign.borderRadius);
        this.buttonBackground.strokeRoundedRect(0, 0, this.buttonWidth, this.buttonHeight, consts_1.buttonDesign.borderRadius);
    }
    destroy() {
        this.unsubscribeFromConnector();
        this.cancelIconChange();
        this.buttonContainer.removeAllListeners();
        this.buttonContainer.destroy();
        super.destroy();
    }
}
exports.ConnectWalletButton = ConnectWalletButton;
