"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DropdownMenu = exports.DropdownMenuItem = void 0;
const consts_1 = require("./consts");
const utils_1 = require("./utils");
class DropdownMenuItem extends Phaser.GameObjects.Container {
    constructor(scene, x = 0, y = 0, params) {
        super(scene, x, y);
        const styleSchema = params.style === 'dark' ? consts_1.buttonDesign.dark : consts_1.buttonDesign.light;
        const text = scene.add.text(consts_1.buttonDesign.dropDownItem.horizontalPadding +
            consts_1.buttonDesign.icon.width +
            consts_1.buttonDesign.dropDownItem.horizontalPadding, consts_1.buttonDesign.dropDownItem.verticalPadding, params.text, {
            color: styleSchema.fontColor,
            fontFamily: consts_1.buttonDesign.fontFamily,
            fontSize: consts_1.buttonDesign.fontSize
        });
        this.text = text;
        const textHeight = text.height;
        const buttonWidth = consts_1.buttonDesign.dropDown.width - consts_1.buttonDesign.dropDown.horizontalPadding * 2;
        const buttonHeight = textHeight + consts_1.buttonDesign.dropDownItem.verticalPadding * 2;
        this.buttonHeight = buttonHeight;
        const icon = scene.add.image(consts_1.buttonDesign.dropDownItem.horizontalPadding + consts_1.buttonDesign.icon.width * 0.5, buttonHeight * 0.5, params.icon);
        this.icon = icon;
        const button = scene.add.graphics({
            x: 0,
            y: 0,
            fillStyle: { color: (0, utils_1.hexToNumber)(styleSchema.backgroundColor) }
        });
        button.fillRoundedRect(0, 0, buttonWidth, buttonHeight, 8);
        button.setInteractive(new Phaser.Geom.Rectangle(0, 0, buttonWidth, buttonHeight), Phaser.Geom.Rectangle.Contains);
        button.on('pointerover', () => {
            scene.game.canvas.style.cursor = 'pointer';
            button.clear();
            button.fillStyle((0, utils_1.hexToNumber)(styleSchema.backgroundColorHover));
            button.lineStyle(consts_1.buttonDesign.borderWidth, (0, utils_1.hexToNumber)(styleSchema.borderColor));
            button.fillRoundedRect(0, 0, buttonWidth, buttonHeight, 8);
        });
        button.on('pointerout', () => {
            scene.game.canvas.style.cursor = 'default';
            button.clear();
            button.fillStyle((0, utils_1.hexToNumber)(styleSchema.backgroundColor));
            button.lineStyle(consts_1.buttonDesign.borderWidth, (0, utils_1.hexToNumber)(styleSchema.borderColor));
            button.fillRoundedRect(0, 0, buttonWidth, buttonHeight, 8);
            (0, utils_1.smoothScale)(scene.tweens, this, 1, 125);
        });
        button.on('pointerdown', () => {
            (0, utils_1.smoothScale)(scene.tweens, this, 0.98, 125);
        });
        button.on('pointerup', () => {
            (0, utils_1.smoothScale)(scene.tweens, this, 1, 125);
        });
        this.button = button;
        if (params.onClick) {
            button.setInteractive({ useHandCursor: true });
            button.on('pointerdown', () => {
                params.onClick && params.onClick(this);
            });
        }
        this.add([button, icon, text]);
    }
}
exports.DropdownMenuItem = DropdownMenuItem;
class DropdownMenu extends Phaser.GameObjects.Container {
    constructor(scene, x = 0, y = 0, params) {
        super(scene, x, y);
        const styleSchema = params.style === 'dark' ? consts_1.buttonDesign.dark : consts_1.buttonDesign.light;
        const itemsContainers = [];
        let totalHeight = consts_1.buttonDesign.dropDown.verticalPadding;
        params.items.forEach((item) => {
            const itemContainer = new DropdownMenuItem(scene, consts_1.buttonDesign.dropDown.horizontalPadding, totalHeight, Object.assign(Object.assign({}, item), { style: params.style }));
            totalHeight += itemContainer.buttonHeight;
            itemsContainers.push(itemContainer);
        });
        totalHeight += consts_1.buttonDesign.dropDown.verticalPadding;
        const container = scene.add.graphics({
            x: 0,
            y: 0,
            fillStyle: { color: (0, utils_1.hexToNumber)(styleSchema.backgroundColor) },
            lineStyle: { width: consts_1.buttonDesign.borderWidth, color: (0, utils_1.hexToNumber)(styleSchema.borderColor) }
        });
        container.fillRoundedRect(0, 0, consts_1.buttonDesign.dropDown.width, totalHeight, consts_1.buttonDesign.dropDown.borderRadius);
        container.strokeRoundedRect(0, 0, consts_1.buttonDesign.dropDown.width, totalHeight, consts_1.buttonDesign.dropDown.borderRadius);
        this.add([container, ...itemsContainers]);
    }
}
exports.DropdownMenu = DropdownMenu;
